@@ -7,24 +7,18 @@ import operator
 import sys
 import types
 
-import six
-
 from webob import (Request as WebObRequest, Response as WebObResponse, exc,
                    acceptparse)
 from webob.multidict import NestedMultiDict
 
-from .compat import urlparse, izip
+from .compat import urlparse, izip, is_bound_method as ismethod
 from .jsonify import encode as dumps
 from .secure import handle_security
 from .templating import RendererFactory
 from .routing import lookup_controller, NonCanonicalPath
-from .util import _cfg, encode_if_needed, getargspec
+from .util import _cfg, getargspec
 from .middleware.recursive import ForwardRequestException
 
-if six.PY3:
-    from .compat import is_bound_method as ismethod
-else:
-    from inspect import ismethod
 
 # make sure that json is defined in mimetypes
 add_type('application/json', '.json', True)
@@ -130,12 +124,7 @@ def abort(status_code, detail='', headers=None, comment=None, **kw):
             comment=comment,
             **kw
         )
-
-        if six.PY3:
-            raise webob_exception.with_traceback(traceback)
-        else:
-            # Using exec to avoid python 3 parsers from crashing
-            exec('raise webob_exception, None, traceback')
+        raise webob_exception.with_traceback(traceback)
     finally:
         # Per the suggestion of the Python docs, delete the traceback object
         del traceback
@@ -236,7 +225,7 @@ class PecanBase(object):
                  force_canonical=True, guess_content_type_from_ext=True,
                  context_local_factory=None, request_cls=Request,
                  response_cls=Response, **kw):
-        if isinstance(root, six.string_types):
+        if isinstance(root, str):
             root = self.__translate_root__(root)
 
         self.root = root
@@ -246,7 +235,7 @@ class PecanBase(object):
         self.default_renderer = default_renderer
 
         # pre-sort these so we don't have to do it per-request
-        if six.callable(hooks):
+        if callable(hooks):
             hooks = hooks()
 
         self.hooks = list(sorted(
@@ -275,7 +264,7 @@ class PecanBase(object):
             module = __import__(name, fromlist=fromlist)
             kallable = getattr(module, parts[-1])
             msg = "%s does not represent a callable class or function."
-            if not six.callable(kallable):
+            if not callable(kallable):
                 raise TypeError(msg % item)
             return kallable()
 
@@ -397,9 +386,9 @@ class PecanBase(object):
 
         # handle wildcard GET/POST params
         if argspec[2]:
-            for name, value in six.iteritems(all_params):
+            for name, value in iter(all_params.items()):
                 if name not in argspec[0]:
-                    kwargs[encode_if_needed(name)] = value
+                    kwargs[name] = value
 
         return args, varargs, kwargs
 
@@ -412,6 +401,11 @@ class PecanBase(object):
                 renderer_name,
                 self.template_path
             )
+            if renderer is None:
+                raise RuntimeError(
+                    'support for "%s" was not found; ' % renderer_name +
+                    'supported template engines are %s' % self.renderers.keys()
+                )
         else:
             renderer = self.renderers.get(
                 self.default_renderer,
@@ -461,7 +455,7 @@ class PecanBase(object):
         # handle generic controllers
         im_self = None
         if cfg.get('generic'):
-            im_self = six.get_method_self(controller)
+            im_self = controller.__self__
             handlers = cfg['generic_handlers']
             controller = handlers.get(req.method, handlers['DEFAULT'])
             handle_security(controller, im_self)
@@ -475,7 +469,7 @@ class PecanBase(object):
         if not pecan_state['content_type']:
             # attempt to find a best match based on accept headers (if they
             # exist)
-            accept = getattr(req.accept, 'header_value', '*/*')
+            accept = getattr(req.accept, 'header_value', '*/*') or '*/*'
             if accept == '*/*' or (
                     accept.startswith('text/html,') and
                     list(content_types.keys()) in self.SIMPLEST_CONTENT_TYPES):
@@ -484,11 +478,21 @@ class PecanBase(object):
                     'text/html'
                 )
             else:
-                best_default = acceptparse.MIMEAccept(
-                    accept
-                ).best_match(
-                    content_types.keys()
+                best_default = None
+                accept_header = acceptparse.create_accept_header(accept)
+                offers = accept_header.acceptable_offers(
+                    list(content_types.keys())
                 )
+                if offers:
+                    # If content type matches exactly use matched type
+                    best_default = offers[0][0]
+                else:
+                    # If content type doesn't match exactly see if something
+                    # matches when not using parameters
+                    for k in content_types.keys():
+                        if accept.startswith(k):
+                            best_default = k
+                            break
 
                 if best_default is None:
                     msg = "Controller '%s' defined does not support " + \
@@ -607,7 +611,7 @@ class PecanBase(object):
             testing_variables['controller_output'] = result
 
         # set the body content
-        if result and isinstance(result, six.text_type):
+        if result and isinstance(result, str):
             resp.text = result
         elif result:
             resp.body = result
@@ -680,9 +684,11 @@ class PecanBase(object):
             # if this is an HTTP Exception, set it as the response
             if isinstance(e, exc.HTTPException):
                 # if the client asked for JSON, do our best to provide it
-                best_match = acceptparse.MIMEAccept(
-                    getattr(req.accept, 'header_value', '*/*')
-                ).best_match(('text/plain', 'text/html', 'application/json'))
+                accept_header = acceptparse.create_accept_header(
+                    getattr(req.accept, 'header_value', '*/*') or '*/*')
+                offers = accept_header.acceptable_offers(
+                    ('text/plain', 'text/html', 'application/json'))
+                best_match = offers[0][0] if offers else None
                 state.response = e
                 if best_match == 'application/json':
                     json_body = dumps({
@@ -690,7 +696,7 @@ class PecanBase(object):
                         'title': e.title,
                         'description': e.detail
                     })
-                    if isinstance(json_body, six.text_type):
+                    if isinstance(json_body, str):
                         e.text = json_body
                     else:
                         e.body = json_body
