@@ -1,9 +1,7 @@
 import os
-import sys
 import tempfile
 import unittest
 
-from six import b as b_
 from webtest import TestApp
 
 import pecan
@@ -21,6 +19,16 @@ class TestConf(PecanTestCase):
         bad_dict = {'bad name': 'value'}
         self.assertRaises(ValueError, configuration.Config, bad_dict)
 
+    def test_update_config_fail_message(self):
+        """When failing, the __force_dict__ key is suggested"""
+        from pecan import configuration
+        bad_dict = {'bad name': 'value'}
+
+        try:
+            configuration.Config(bad_dict)
+        except ValueError as error:
+            assert "consider using the '__force_dict__'" in str(error)
+
     def test_update_set_config(self):
         """Update an empty configuration with the default values"""
         from pecan import configuration
@@ -138,7 +146,7 @@ class TestConf(PecanTestCase):
     def test_config_with_syntax_error(self):
         from pecan import configuration
         with tempfile.NamedTemporaryFile('wb') as f:
-            f.write(b_('\n'.join(['if false', 'var = 3'])))
+            f.write(b'\n'.join([b'if false', b'var = 3']))
             f.flush()
             configuration.Config({})
 
@@ -151,7 +159,7 @@ class TestConf(PecanTestCase):
     def test_config_with_non_package_relative_import(self):
         from pecan import configuration
         with tempfile.NamedTemporaryFile('wb', suffix='.py') as f:
-            f.write(b_('\n'.join(['from . import variables'])))
+            f.write(b'\n'.join([b'from . import variables']))
             f.flush()
             configuration.Config({})
 
@@ -328,7 +336,7 @@ class TestConfFromEnv(PecanTestCase):
     def test_invalid_path(self):
         os.environ['PECAN_CONFIG'] = '/'
         msg = "PECAN_CONFIG was set to an invalid path: /"
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             RuntimeError,
             msg,
             self.get_conf_path_from_env
@@ -337,7 +345,7 @@ class TestConfFromEnv(PecanTestCase):
     def test_is_not_set(self):
         msg = "PECAN_CONFIG is not set and " \
               "no config file was passed as an argument."
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             RuntimeError,
             msg,
             self.get_conf_path_from_env
